@@ -10,7 +10,7 @@ use Net::SSLLabs::Endpoint();
 use Net::SSLLabs::StatusCodes();
 use Encode();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub new {
     my ($class) = @_;
@@ -107,7 +107,7 @@ Net::SSLLabs - An interface to the ssllabs.com service
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -137,11 +137,11 @@ a new I<Net::SSLLabs> object, ready to process TLS services
 
 =head2 info
 
-This call should be used to check the availability of the SSL Labs servers, retrieve the engine and criteria version, and initialize the maximum number of concurrent assessments. Returns one I<Net::SSLLabs::Info> object on success.
+This call should be used to check the availability of the SSL Labs servers, retrieve the engine and criteria version, and initialize the maximum number of concurrent assessments. Returns one L<Net::SSLLabs::Info|Net::SSLLabs::Info> object on success.
 
 =head2 analyze
 
-This call is used to initiate an assessment, or to retrieve the status of an assessment in progress or in the cache. It will return a single I<Net::SSLLabs::Host> object on success. The I<Net::SSLLabs::Endpoint> object embedded in the I<Net:SSLLabs::Host> object will provide partial endpoint results.
+This call is used to initiate an assessment, or to retrieve the status of an assessment in progress or in the cache. It will return a single L<Net::SSLLabs::Host|Net::SSLLabs::Host> object on success. The L<Net::SSLLabs::Endpoint|Net::SSLLabs::Endpoint> object embedded in the L<Net::SSLLabs::Host|Net::SSLLabs::Host> object will provide partial endpoint results.
 
 Parameters:
 
@@ -165,7 +165,7 @@ Parameters:
 
 =head2 getEndpointData
 
-This call is used to retrieve detailed endpoint information. It will return a single I<Net::SSLLabs::Endpoint> object on success. The object will contain complete assessment information. This call does not initiate new assessments, even when a cached report is not found.
+This call is used to retrieve detailed endpoint information. It will return a single L<Net::SSLLabs::Endpoint|Net::SSLLabs::Endpoint> object on success. The object will contain complete assessment information. This call does not initiate new assessments, even when a cached report is not found.
 
 Parameters:
 
@@ -181,7 +181,7 @@ Parameters:
 
 =head2 getStatusCodes
 
-This call will return one I<Net::SSLLabs::StatusCodes> instance.
+This call will return one L<Net::SSLLabs::StatusCodes|Net::SSLLabs::StatusCodes> instance.
 
 =head1 AUTHOR
 
