@@ -160,11 +160,11 @@ a number that represents revocation information present in the certificate:
 
 =head2 crlURIs
 
-list of CRL I<URI>s extracted from the certificate.
+list of CRL L<URI|URI>s extracted from the certificate.
 
 =head2 ocspURIs
 
-list of OCSP I<URI>s extracted from the certificate
+list of OCSP L<URI|URI>s extracted from the certificate
 
 =head2 revocationStatus
 
