@@ -36,4 +36,4 @@ a new I<Net::SSLLabs::SimDetails> object, accepts a JSON object as it's paramete
 
 =head2 results
 
-list of instances of I<Net::SSLLabs::Simulation>.
+list of instances of L<Net::SSLLabs::Simulation|Net::SSLLabs::Simulation>.
