@@ -52,7 +52,7 @@ a new I<Net::SSLLabs::Simulation> object, accepts a JSON object as it's paramete
 
 =head2 client
 
-instance of I<Net::SSLLabs::SimClient>.
+instance of L<Net::SSLLabs::SimClient|Net::SSLLabs::SimClient>.
 
 =head2 errorCode
 
