@@ -41,7 +41,7 @@ a new I<Net::SSLLabs::Suites> object, accepts a JSON object as it's parameter.
 
 =head2 list
 
-list of I<Net::SSLLabs::Suite> objects
+list of L<Net::SSLLabs::Suite|Net::SSLLabs::Suite> objects
 
 =head2 preference
 
